@@ -53,6 +53,7 @@ from .resolve import (
     get_has_parts,
     get_homepage,
     get_identifiers_org_prefix,
+    get_jskos_download,
     get_json_download,
     get_keywords,
     get_license,
@@ -88,6 +89,7 @@ from .resolve import (
     get_repository,
     get_repository_to_prefix,
     get_resource,
+    get_skos_download,
     get_synonyms,
     get_version,
     get_versions,
@@ -197,6 +199,7 @@ __all__ = [
     "get_identifiers_org_iri",
     "get_identifiers_org_prefix",
     "get_iri",
+    "get_jskos_download",
     "get_json_download",
     "get_keywords",
     "get_license",
@@ -247,6 +250,7 @@ __all__ = [
     "get_repository",
     "get_repository_to_prefix",
     "get_resource",
+    "get_skos_download",
     "get_synonyms",
     "get_uri_format",
     "get_uri_prefix",
