@@ -5,7 +5,7 @@ from typing import cast
 from flask import current_app
 from werkzeug.local import LocalProxy
 
-from bioregistry.resource_manager import Manager
+from ..resource_manager import Manager
 
 __all__ = [
     "manager",
