@@ -10,15 +10,28 @@ import random
 import sys
 import typing
 from collections import Counter, defaultdict
-from collections.abc import Collection, Mapping
-from typing import TYPE_CHECKING, Any, Callable, TypeVar, cast
+from collections.abc import Callable, Collection, Mapping
+from typing import TYPE_CHECKING, Any, TypeAlias, TypeVar, cast
 
 import click
-import numpy as np
-from typing_extensions import TypeAlias
 
-import bioregistry
-from bioregistry import (
+from .bibliometrics import (
+    count_publication_years,
+    get_oldest_publications,
+    get_publications_df,
+)
+from .constants import (
+    DOCS_IMG,
+    EXPORT_REGISTRY,
+    INTERNAL_COLOR,
+    INTERNAL_KEY,
+    INTERNAL_LABEL,
+    INTERNAL_PIP,
+    INTERNAL_REPOSITORY,
+)
+from .license_standardizer import standardize_license
+from .metaresource_api import get_registry_short_name
+from .resolve import (
     get_contact_email,
     get_description,
     get_example,
@@ -30,35 +43,27 @@ from bioregistry import (
     get_obo_download,
     get_owl_download,
     get_pattern,
-    get_uri_format,
     get_version,
     is_deprecated,
-    manager,
-    read_registry,
 )
-from bioregistry.bibliometrics import (
-    count_publication_years,
-    get_oldest_publications,
-    get_publications_df,
-)
-from bioregistry.constants import DOCS_IMG, EXPORT_REGISTRY
-from bioregistry.license_standardizer import standardize_license
-from bioregistry.schema import Resource
+from .resource_manager import manager
+from .schema import Resource
+from .schema_utils import read_registry
+from .uri_format import get_uri_format
 
 if TYPE_CHECKING:
     import matplotlib.axes
     import matplotlib.figure
+    import numpy as np
 
 logger = logging.getLogger(__name__)
 
 X = TypeVar("X")
 
-# see named colors https://matplotlib.org/stable/gallery/color/named_colors.html
-BIOREGISTRY_COLOR = "silver"
 BAR_SKIP = {"re3data", "bartoc"}
 
 FigAxPair = tuple["matplotlib.figure.Figure", "matplotlib.axes.Axes"]
-FigMultiAxPair = tuple["matplotlib.figure.Figure", np.ndarray[Any, "matplotlib.axes.Axes"]]  # type:ignore
+FigMultiAxPair = tuple["matplotlib.figure.Figure", "np.ndarray[Any, 'matplotlib.axes.Axes']"]  # type:ignore
 
 
 class RegistryInfo(typing.NamedTuple):
@@ -92,7 +97,7 @@ def _get_has_present(func: Callable[[str], X | None]) -> Counter[X]:
 
 SINGLE_FIG = (8.25, 3.5)
 TODAY = datetime.datetime.today().strftime("%Y-%m-%d")
-WATERMARK_TEXT = f"https://github.com/biopragmatics/bioregistry ({TODAY})"
+WATERMARK_TEXT = f"{INTERNAL_REPOSITORY} ({TODAY})"
 
 
 def _save(
@@ -121,7 +126,7 @@ def _save(
     plt.close(fig)
 
 
-def plot_attribute_pies(watermark: bool) -> FigMultiAxPair:  # type:ignore[type-var]
+def plot_attribute_pies(watermark: bool) -> FigMultiAxPair:
     """Plot how many entries have version information."""
     licenses_mapped = _get_licenses_mapped_counter()
     licenses_mapped_counter = Counter(licenses_mapped)
@@ -178,7 +183,7 @@ def _plot_attribute_pies(
             continue
         label, counter = label_counter
         if label == "License Type":
-            labels, sizes = zip(*counter.most_common())
+            labels, sizes = zip(*counter.most_common(), strict=False)
             explode = None
         else:
             labels = ("Yes", "No")
@@ -217,14 +222,14 @@ def make_overlaps(keys: list[RegistryInfo]) -> OverlapsHint:
     """Make overlaps dictionary."""
     rv = {}
     for metaprefix, _, _, prefixes in keys:
-        # Remap bioregistry prefixes to match the external
+        # Remap internal prefixes to match the external
         #  vocabulary, when possible
-        bioregistry_remapped = {
+        internal_remapped = {
             resource.get_external(metaprefix).get("prefix", prefix)
-            for prefix, resource in bioregistry.read_registry().items()
+            for prefix, resource in read_registry().items()
         }
         rv[metaprefix] = {
-            REMAPPED_KEY: bioregistry_remapped,
+            REMAPPED_KEY: internal_remapped,
             REMAPPED_VALUE: prefixes,
         }
     return rv
@@ -246,11 +251,11 @@ def plot_overlap_venn_diagrams(
             ax.axis("off")
             continue
         key, label, color, prefixes = key
-        bioregistry_remapped = overlaps[key][REMAPPED_KEY]
+        internal_remapped = overlaps[key][REMAPPED_KEY]
         venn2(
-            subsets=(bioregistry_remapped, prefixes),
-            set_labels=("Bioregistry", label),
-            set_colors=(BIOREGISTRY_COLOR, color),
+            subsets=(internal_remapped, prefixes),
+            set_labels=(INTERNAL_LABEL, label),
+            set_colors=(INTERNAL_COLOR, color),
             ax=ax,
         )
     if watermark:
@@ -283,7 +288,7 @@ def _plot_external_overlap(
             ax.axis("off")
             continue
         (l_key, l_label, l_color, l_prefixes), (r_key, r_label, r_color, r_prefixes) = pair
-        # Remap external vocabularies to bioregistry
+        # Remap external vocabularies to internal
         #  prefixes, when possible
         l_prefixes = _remap(key=l_key, prefixes=l_prefixes)
         r_prefixes = _remap(key=r_key, prefixes=r_prefixes)
@@ -311,11 +316,11 @@ def get_getters() -> list[tuple[str, str, Callable]]:  # type:ignore
     """Get getter functions, which requires alignment dependencies."""
     # FIXME replace with class_resolver
     try:
-        from bioregistry.external import GETTERS
+        from .external import GETTERS
     except ImportError:
         click.secho(
             "Could not import alignment dependencies."
-            " Install bioregistry again with `pip install bioregistry[align]`.",
+            f" Install {INTERNAL_LABEL} again with `pip install {INTERNAL_PIP}[align]`.",
             fg="red",
         )
         return sys.exit(1)
@@ -334,7 +339,7 @@ def get_registry_infos() -> list[RegistryInfo]:
         palette = sns.color_palette("Paired", len(getters))
     return [
         RegistryInfo(metaprefix, label, color, set(func(force_download=False)))
-        for (metaprefix, label, func), color in zip(getters, palette)
+        for (metaprefix, label, func), color in zip(getters, palette, strict=False)
     ]
 
 
@@ -373,7 +378,7 @@ def compare() -> None:
     except ImportError:
         click.secho(
             "Could not import matplotlib dependencies."
-            " Install bioregistry again with `pip install bioregistry[charts]`.",
+            f" Install {INTERNAL_LABEL} again with `pip install {INTERNAL_PIP}[charts]`.",
             fg="red",
         )
         sys.exit(1)
@@ -394,13 +399,13 @@ def compare() -> None:
     _save(fig, name="xrefs", png=paper, pdf=paper)
 
     fig, _ = plot_coverage_gains(overlaps=overlaps)
-    _save(fig, name="bioregistry_coverage_bar", png=paper, pdf=paper)
+    _save(fig, name=f"{INTERNAL_KEY}_coverage_bar", png=paper, pdf=paper)
 
     fig, _ = plot_overlap_venn_diagrams(keys=registry_infos, overlaps=overlaps, watermark=watermark)
-    _save(fig, name="bioregistry_coverage")
+    _save(fig, name=f"{INTERNAL_KEY}_coverage")
 
     fig, _ = plot_coverage_overlaps(overlaps=overlaps)
-    _save(fig, name="bioregistry_coverage_bar_short")
+    _save(fig, name=f"{INTERNAL_KEY}_coverage_bar_short")
 
     fig, _ = plot_attribute_pies(watermark=watermark)
     _save(fig, "has_attribute")
@@ -521,7 +526,7 @@ def plot_coverage_overlaps(*, overlaps: OverlapsHint) -> FigAxPair:
         br, external = data[REMAPPED_KEY], data[REMAPPED_VALUE]
         rows.append(
             (
-                bioregistry.get_registry_short_name(metaprefix),
+                get_registry_short_name(metaprefix),
                 len(external - br),
                 len(br.intersection(external)),
             )
@@ -542,7 +547,7 @@ def plot_coverage_overlaps(*, overlaps: OverlapsHint) -> FigAxPair:
     )
     ax.grid(False)
     ax.set_ylabel("")
-    ax.set_xticks([])  # type:ignore[operator]
+    ax.set_xticks([])
     ax.spines["top"].set_visible(False)
     ax.spines["right"].set_visible(False)
     ax.spines["bottom"].set_visible(False)
@@ -595,24 +600,26 @@ def plot_coverage_gains(*, overlaps: OverlapsHint, minimum_width_for_text: int =
     for metaprefix, data in overlaps.items():
         if metaprefix in BAR_SKIP:
             continue
-        # Get the set of remapped bioregistry prefixes
-        bioregistry_prefixes = data[REMAPPED_KEY]
+        # Get the set of remapped internal prefixes
+        internal_prefixes = data[REMAPPED_KEY]
         # Get the set of prefixes from the registry with the given metaprefix
         external_prefixes = data[REMAPPED_VALUE]
         rows.append(
             (
-                bioregistry.get_registry_short_name(metaprefix),
-                # (blue) The number of external prefixes that were not mapped to bioregistry prefixes
-                len(external_prefixes - bioregistry_prefixes),
-                # (orange) The number of external prefixes that were mapped to bioregistry prefixes
-                len(bioregistry_prefixes.intersection(external_prefixes)),
-                # (green) The number of bioregistry prefixes that were not mapped to external prefixes
-                len(bioregistry_prefixes - external_prefixes),
+                get_registry_short_name(metaprefix),
+                # (blue) The number of external prefixes that were not mapped to internal prefixes
+                len(external_prefixes - internal_prefixes),
+                # (orange) The number of external prefixes that were mapped to interanal prefixes
+                len(internal_prefixes.intersection(external_prefixes)),
+                # (green) The number of internal prefixes that were not mapped to external prefixes
+                len(internal_prefixes - external_prefixes),
             )
         )
     rows = sorted(rows, key=lambda row: sum(row[1:]), reverse=True)
 
-    df = pd.DataFrame(rows, columns=["metaprefix", "External Only", "Mapped", "Bioregistry Only"])
+    df = pd.DataFrame(
+        rows, columns=["metaprefix", "External Only", "Mapped", f"{INTERNAL_LABEL} Only"]
+    )
     df.set_index("metaprefix", inplace=True)
 
     fig, ax = plt.subplots(1, 1, figsize=(10, 7.5))
@@ -629,7 +636,7 @@ def plot_coverage_gains(*, overlaps: OverlapsHint, minimum_width_for_text: int =
     )
     plt.legend()
     ax.set_ylabel("")
-    ax.set_xticks([])  # type:ignore[operator]
+    ax.set_xticks([])
     ax.grid(False)
     ax.spines["top"].set_visible(False)
     ax.spines["right"].set_visible(False)
@@ -721,7 +728,7 @@ def plot_xrefs(registry_infos: list[RegistryInfo], watermark: bool) -> FigAxPair
     # There should only be one container here
     _labels = xrefs_df["count"].to_list()
     _labels[0] = f"{_labels[0]}\nNovel"
-    for i, label in zip(ax.containers, _labels):  # type:ignore[attr-defined]
+    for i, label in zip(ax.containers, _labels, strict=False):  # type:ignore[attr-defined]
         ax.bar_label(i, [label])
     ax.set_xlabel(
         f"Number of the {n_mappable_metaprefixes} Mapped External Registries Capturing a Given Identifier Resource"
@@ -765,7 +772,7 @@ def plot_xrefs(registry_infos: list[RegistryInfo], watermark: bool) -> FigAxPair
 
 
 def _get_licenses_mapped_counter(threshold: int = 30) -> list[str]:
-    licenses, conflicts, obo_has_license, ols_has_license = _get_license_and_conflicts()
+    licenses, _conflicts, _obo_has_license, _ols_has_license = _get_license_and_conflicts()
     licenses_counter: typing.Counter[str] = Counter(licenses)
     licenses_mapped = [
         (
