@@ -6,6 +6,12 @@ from tabulate import tabulate
 import bioregistry
 from bioregistry.constants import DISALLOWED_EMAIL_PARTS
 
+#: emails that are actually from people, but might get flagged as not
+ALLOWLIST = {
+    "allyson.lister@oerc.ox.ac.uk",
+    "alistair.miles@linacre.ox.ac.uk",
+}
+
 
 @click.command()
 def main() -> None:
@@ -15,7 +21,11 @@ def main() -> None:
         contact = resource.get_contact()
         if not contact or not contact.email:
             continue
-        if any(p in contact.email for p in DISALLOWED_EMAIL_PARTS | {"help", "list"}):
+        if contact.email in ALLOWLIST:
+            continue
+        if any(p in contact.email for p in DISALLOWED_EMAIL_PARTS | {"help", "list"}) or any(
+            p in contact.name.lower() for p in {"helpdesk", "support"}
+        ):
             publications = resource.get_publications()
             if publications:
                 url = publications[0].get_url()
