@@ -5,17 +5,15 @@ from __future__ import annotations
 import logging
 import typing
 from collections import Counter, defaultdict
-from collections.abc import Iterable, Mapping, Sequence
+from collections.abc import Callable, Iterable, Mapping, Sequence
 from dataclasses import dataclass
 from functools import cache
 from pathlib import Path
 from typing import (
     Any,
-    Callable,
     Generic,
     Literal,
     TypeVar,
-    Union,
     cast,
     overload,
 )
@@ -69,7 +67,7 @@ __all__ = [
 
 logger = logging.getLogger(__name__)
 
-X = TypeVar("X", bound=Union[int, str])
+X = TypeVar("X", bound=int | str)
 
 
 @dataclass
@@ -150,17 +148,21 @@ class Manager:
         """Instantiate a registry manager.
 
         :param registry: A custom registry. If none given, defaults to the Bioregistry.
-        :param metaregistry: A custom metaregistry. If none, defaults to the Bioregistry's metaregistry.
-        :param collections: A custom collections dictionary. If none, defaults to the Bioregistry's collections.
-        :param contexts: A custom contexts dictionary. If none, defaults to the Bioregistry's contexts.
-        :param mismatches: A custom mismatches dictionary. If none, defaults to the Bioregistry's mismatches.
+        :param metaregistry: A custom metaregistry. If none, defaults to the
+            Bioregistry's metaregistry.
+        :param collections: A custom collections dictionary. If none, defaults to the
+            Bioregistry's collections.
+        :param contexts: A custom contexts dictionary. If none, defaults to the
+            Bioregistry's contexts.
+        :param mismatches: A custom mismatches dictionary. If none, defaults to the
+            Bioregistry's mismatches.
         :param base_url: The base URL.
         """
         self.base_url = (base_url or BIOREGISTRY_REMOTE_URL).rstrip()
 
         if registry is None:
             self.registry = dict(_registry_from_path(BIOREGISTRY_PATH))
-        elif isinstance(registry, (str, Path)):
+        elif isinstance(registry, str | Path):
             self.registry = dict(_registry_from_path(registry))
         else:
             self.registry = dict(registry)
@@ -168,21 +170,21 @@ class Manager:
 
         if metaregistry is None:
             self.metaregistry = dict(_read_metaregistry(METAREGISTRY_PATH))
-        elif isinstance(metaregistry, (str, Path)):
+        elif isinstance(metaregistry, str | Path):
             self.metaregistry = dict(_read_metaregistry(metaregistry))
         else:
             self.metaregistry = dict(metaregistry)
 
         if collections is None:
             self.collections = dict(_collections_from_path(COLLECTIONS_PATH))
-        elif isinstance(collections, (str, Path)):
+        elif isinstance(collections, str | Path):
             self.collections = dict(_collections_from_path(collections))
         else:
             self.collections = dict(collections)
 
         if contexts is None:
             self.contexts = dict(_contexts_from_path(CONTEXTS_PATH))
-        elif isinstance(contexts, (str, Path)):
+        elif isinstance(contexts, str | Path):
             self.contexts = dict(_contexts_from_path(contexts))
         else:
             self.contexts = dict(contexts)
@@ -314,17 +316,18 @@ class Manager:
     ) -> str | None:
         """Get the normalized prefix, or return None if not registered.
 
-        :param prefix: The prefix to normalize, which could come from Bioregistry,
-            OBO Foundry, OLS, or any of the curated synonyms in the Bioregistry
+        :param prefix: The prefix to normalize, which could come from Bioregistry, OBO
+            Foundry, OLS, or any of the curated synonyms in the Bioregistry
         :param strict: If true and the prefix could not be looked up, raises an error
-        :param use_preferred:
-            If set to true, uses the "preferred prefix", if available, instead
-            of the canonicalized Bioregistry prefix.
-        :returns: The canonical Bioregistry prefix, it could be looked up. This
-            will usually take precedence: MIRIAM, OBO Foundry / OLS, Custom except
-            in a few cases, such as NCBITaxon.
+        :param use_preferred: If set to true, uses the "preferred prefix", if available,
+            instead of the canonicalized Bioregistry prefix.
 
-        :raises PrefixStandardizationError: If strict is set to true and the prefix could not be standardized
+        :returns: The canonical Bioregistry prefix, it could be looked up. This will
+            usually take precedence: MIRIAM, OBO Foundry / OLS, Custom except in a few
+            cases, such as NCBITaxon.
+
+        :raises PrefixStandardizationError: If strict is set to true and the prefix
+            could not be standardized
         """
         norm_prefix = self.synonyms.get(prefix)
         if norm_prefix is None:
@@ -346,11 +349,12 @@ class Manager:
     def get_resource(self, prefix: str, *, strict: bool = False) -> Resource | None:
         """Get the Bioregistry entry for the given prefix.
 
-        :param prefix: The prefix to look up, which is normalized with :func:`normalize_prefix`
-            before lookup in the Bioregistry
+        :param prefix: The prefix to look up, which is normalized with
+            :func:`normalize_prefix` before lookup in the Bioregistry
         :param strict: If true, requires the prefix to be valid or raise an exveption
-        :returns: The Bioregistry entry dictionary, which includes several keys cross-referencing
-            other registries when available.
+
+        :returns: The Bioregistry entry dictionary, which includes several keys
+            cross-referencing other registries when available.
         """
         norm_prefix = self.normalize_prefix(prefix)
         if norm_prefix is None:
@@ -390,56 +394,58 @@ class Manager:
         """Parse a compact identifier from a URI.
 
         :param uri: A valid URI
-        :param use_preferred:
-            If set to true, uses the "preferred prefix", if available, instead
-            of the canonicalized Bioregistry prefix.
-        :param on_failure_return_type: whether to return a single None or a pair of None's
+        :param use_preferred: If set to true, uses the "preferred prefix", if available,
+            instead of the canonicalized Bioregistry prefix.
+        :param on_failure_return_type: whether to return a single None or a pair of
+            None's
 
-        :return: A pair of prefix/identifier, if can be parsed
+        :returns: A pair of prefix/identifier, if can be parsed
 
         IRI from an OBO PURL:
 
         >>> from bioregistry import manager
         >>> manager.parse_uri("http://purl.obolibrary.org/obo/DRON_00023232")
-        ReferenceTuple('dron', '00023232')
+        ReferenceTuple(prefix='dron', identifier='00023232')
 
         IRI from the OLS:
 
         >>> manager.parse_uri(
         ...     "https://www.ebi.ac.uk/ols/ontologies/ecao/terms?iri=http://purl.obolibrary.org/obo/ECAO_0107180"
         ... )  # noqa:E501
-        ReferenceTuple('ecao', '0107180')
+        ReferenceTuple(prefix='ecao', identifier='0107180')
 
         IRI from native provider
 
         >>> manager.parse_uri("https://www.alzforum.org/mutations/1234")
-        ReferenceTuple('alzforum.mutation', '1234')
+        ReferenceTuple(prefix='alzforum.mutation', identifier='1234')
 
         Dog food:
 
         >>> manager.parse_uri("https://bioregistry.io/DRON:00023232")
-        ReferenceTuple('dron', '00023232')
+        ReferenceTuple(prefix='dron', identifier='00023232')
 
         IRIs from Identifiers.org (https and http, colon and slash):
 
         >>> manager.parse_uri("https://identifiers.org/aop.relationships:5")
-        ReferenceTuple('aop.relationships', '5')
+        ReferenceTuple(prefix='aop.relationships', identifier='5')
         >>> manager.parse_uri("http://identifiers.org/aop.relationships:5")
-        ReferenceTuple('aop.relationships', '5')
+        ReferenceTuple(prefix='aop.relationships', identifier='5')
         >>> manager.parse_uri("https://identifiers.org/aop.relationships/5")
-        ReferenceTuple('aop.relationships', '5')
+        ReferenceTuple(prefix='aop.relationships', identifier='5')
         >>> manager.parse_uri("http://identifiers.org/aop.relationships/5")
-        ReferenceTuple('aop.relationships', '5')
+        ReferenceTuple(prefix='aop.relationships', identifier='5')
 
         IRI from N2T
+
         >>> manager.parse_uri("https://n2t.net/aop.relationships:5")
-        ReferenceTuple('aop.relationships', '5')
+        ReferenceTuple(prefix='aop.relationships', identifier='5')
 
         Handle either HTTP or HTTPS:
+
         >>> manager.parse_uri("http://braininfo.rprc.washington.edu/centraldirectory.aspx?ID=268")
-        ReferenceTuple('neuronames', '268')
+        ReferenceTuple(prefix='neuronames', identifier='268')
         >>> manager.parse_uri("https://braininfo.rprc.washington.edu/centraldirectory.aspx?ID=268")
-        ReferenceTuple('neuronames', '268')
+        ReferenceTuple(prefix='neuronames', identifier='268')
 
         If you provide your own prefix map, you should pre-process the prefix map with:
 
@@ -452,7 +458,7 @@ class Manager:
         Corner cases:
 
         >>> manager.parse_uri("https://omim.org/MIM:PS214100")
-        ReferenceTuple('omim.ps', '214100')
+        ReferenceTuple(prefix='omim.ps', identifier='214100')
         """
         reference = self.converter.parse_uri(uri, return_none=True)
         if reference is not None:
@@ -484,10 +490,10 @@ class Manager:
         """Parse a compact uniform resource identifier (CURIE) from a URI.
 
         :param uri: A valid URI
-        :param use_preferred:
-            If set to true, uses the "preferred prefix", if available, instead
-            of the canonicalized Bioregistry prefix.
-        :return: A CURIE, if the URI can be parsed
+        :param use_preferred: If set to true, uses the "preferred prefix", if available,
+            instead of the canonicalized Bioregistry prefix.
+
+        :returns: A CURIE, if the URI can be parsed
 
         URI from an OBO PURL:
 
@@ -524,10 +530,12 @@ class Manager:
         'aop.relationships:5'
 
         URI from N2T
+
         >>> manager.compress("https://n2t.net/aop.relationships:5")
         'aop.relationships:5'
 
         URI from an OBO PURL (with preferred prefix)
+
         >>> manager.compress("http://purl.obolibrary.org/obo/DRON_00023232", use_preferred=True)
         'DRON:00023232'
         """
@@ -697,15 +705,17 @@ class Manager:
 
         :param prefix: The prefix in the CURIE
         :param identifier: The identifier in the CURIE
-        :param use_preferred:
-            If set to true, uses the "preferred prefix", if available, instead
-            of the canonicalized Bioregistry prefix.
-        :param on_failure_return_type: whether to return a single None or a pair of None's
+        :param use_preferred: If set to true, uses the "preferred prefix", if available,
+            instead of the canonicalized Bioregistry prefix.
+        :param on_failure_return_type: whether to return a single None or a pair of
+            None's
         :param strict: If true, raises an error if the prefix can't be standardized
-        :return: A normalized prefix/identifier pair, conforming to Bioregistry standards. This means no redundant
-            prefixes or bananas, all lowercase.
 
-        :raises PrefixStandardizationError: If strict is set to true and the prefix could not be standardized
+        :returns: A normalized prefix/identifier pair, conforming to Bioregistry
+            standards. This means no redundant prefixes or bananas, all lowercase.
+
+        :raises PrefixStandardizationError: If strict is set to true and the prefix
+            could not be standardized
         """
         norm_prefix = self.normalize_prefix(prefix, strict=False)
         if not norm_prefix:
@@ -729,6 +739,7 @@ class Manager:
 
         :param metaprefix: Which external registry should be used?
         :param normalize: Should the external prefixes be normalized?
+
         :returns: A mapping of external prefixes to bioregistry prefies
 
         >>> from bioregistry import manager
@@ -986,14 +997,14 @@ class Manager:
     ) -> Mapping[str, str]:
         """Get a mapping from prefixes to their regular expression patterns.
 
-        :param prefix_priority:
-            The order of metaprefixes OR "preferred" for choosing a primary prefix
-            OR "default" for Bioregistry prefixes
-        :param include_synonyms: Should synonyms of each prefix also be included as additional prefixes, but with
-            the same URI prefix?
+        :param prefix_priority: The order of metaprefixes OR "preferred" for choosing a
+            primary prefix OR "default" for Bioregistry prefixes
+        :param include_synonyms: Should synonyms of each prefix also be included as
+            additional prefixes, but with the same URI prefix?
         :param remapping: A mapping from prefixes to preferred prefixes.
         :param blacklist: Prefixes to skip
-        :return: A mapping from prefixes to regular expression pattern strings.
+
+        :returns: A mapping from prefixes to regular expression pattern strings.
         """
         it = self._iter_pattern_map(
             include_synonyms=include_synonyms, prefix_priority=prefix_priority, blacklist=blacklist
@@ -1036,22 +1047,18 @@ class Manager:
     ) -> curies.Converter:
         """Get a converter from this manager.
 
-        :param prefix_priority:
-            The order of metaprefixes OR "preferred" for choosing a primary prefix
-            OR "default" for Bioregistry prefixes
-        :param uri_prefix_priority:
-            The order of metaprefixes for choosing the primary URI prefix OR
-            "default" for Bioregistry prefixes
+        :param prefix_priority: The order of metaprefixes OR "preferred" for choosing a
+            primary prefix OR "default" for Bioregistry prefixes
+        :param uri_prefix_priority: The order of metaprefixes for choosing the primary
+            URI prefix OR "default" for Bioregistry prefixes
         :param include_prefixes: Should prefixes be included with colon delimiters?
-            Setting this to true makes an "omni"-reverse prefix map that can be
-            used to parse both URIs and CURIEs
-        :param strict:
-            If true, errors on URI prefix collisions. If false, sends logging
+            Setting this to true makes an "omni"-reverse prefix map that can be used to
+            parse both URIs and CURIEs
+        :param strict: If true, errors on URI prefix collisions. If false, sends logging
             and skips them.
         :param remapping: A mapping from bioregistry prefixes to preferred prefixes.
         :param rewiring: A mapping from bioregistry prefixes to new URI prefixes.
-        :param blacklist:
-            A collection of prefixes to skip
+        :param blacklist: A collection of prefixes to skip
         :param enforce_w3c: Should non-W3C-compliant prefix synoynms be removed?
 
         :returns: A list of records for :class:`curies.Converter`
@@ -1123,18 +1130,17 @@ class Manager:
     ) -> Mapping[str, str]:
         """Get a mapping from Bioregistry prefixes to their URI prefixes .
 
-        :param prefix_priority:
-            The order of metaprefixes OR "preferred" for choosing a primary prefix
-            OR "default" for Bioregistry prefixes
-        :param uri_prefix_priority:
-            The order of metaprefixes for choosing the primary URI prefix OR
-            "default" for Bioregistry prefixes
-        :param include_synonyms: Should synonyms of each prefix also be included as additional prefixes, but with
-            the same URI prefix?
+        :param prefix_priority: The order of metaprefixes OR "preferred" for choosing a
+            primary prefix OR "default" for Bioregistry prefixes
+        :param uri_prefix_priority: The order of metaprefixes for choosing the primary
+            URI prefix OR "default" for Bioregistry prefixes
+        :param include_synonyms: Should synonyms of each prefix also be included as
+            additional prefixes, but with the same URI prefix?
         :param remapping: A mapping from Bioregistry prefixes to preferred prefixes.
         :param rewiring: A mapping from Bioregistry prefixes to URI prefixes.
         :param blacklist: Prefixes to skip
-        :return: A mapping from prefixes to URI prefixes.
+
+        :returns: A mapping from prefixes to URI prefixes.
         """
         converter = self.get_converter(
             prefix_priority=prefix_priority,
@@ -1149,10 +1155,10 @@ class Manager:
         r"""Get the CURIE pattern for this resource.
 
         :param prefix: The prefix to look up
-        :param use_preferred:
-            If set to true, uses the "preferred prefix", if available, instead
-            of the canonicalized Bioregistry prefix.
-        :return: The regular expression pattern to match CURIEs against
+        :param use_preferred: If set to true, uses the "preferred prefix", if available,
+            instead of the canonicalized Bioregistry prefix.
+
+        :returns: The regular expression pattern to match CURIEs against
 
         >>> from bioregistry import manager
         >>> manager.get_curie_pattern("go")
@@ -1270,10 +1276,11 @@ class Manager:
         This is complementary to :func:`get_depends_on`.
 
         :param prefix: The prefix to look up
-        :returns: The list of resources this prefix has been annotated to appear in. This
-            list could be incomplete, since curation of these fields can easily get out
-            of sync with curation of the resource itself. However, false positives should
-            be pretty rare.
+
+        :returns: The list of resources this prefix has been annotated to appear in.
+            This list could be incomplete, since curation of these fields can easily get
+            out of sync with curation of the resource itself. However, false positives
+            should be pretty rare.
         """
         resource = self.get_resource(prefix)
         if resource is None:
@@ -1288,10 +1295,11 @@ class Manager:
         This is complementary to :func:`get_appears_in`.
 
         :param prefix: The prefix to look up
-        :returns: The list of resources this prefix has been annotated to depend on. This
-            list could be incomplete, since curation of these fields can easily get out
-            of sync with curation of the resource itself. However, false positives should
-            be pretty rare.
+
+        :returns: The list of resources this prefix has been annotated to depend on.
+            This list could be incomplete, since curation of these fields can easily get
+            out of sync with curation of the resource itself. However, false positives
+            should be pretty rare.
 
         >>> from bioregistry import manager
         >>> assert "bfo" in manager.get_depends_on("foodon")
@@ -1320,8 +1328,10 @@ class Manager:
 
         :param metaprefix: The key for the external registry
         :param metaidentifier: The prefix in the external registry
-        :param normalize: Should external prefixes be normalized during lookup (e.g., lowercased)
-        :return: The bioregistry prefix (if it can be mapped)
+        :param normalize: Should external prefixes be normalized during lookup (e.g.,
+            lowercased)
+
+        :returns: The bioregistry prefix (if it can be mapped)
 
         >>> from bioregistry import manager
         >>> manager.lookup_from("obofoundry", "GO")
@@ -1381,17 +1391,16 @@ class Manager:
     def get_parts_collections(self) -> Mapping[str, list[str]]:
         """Group resources' prefixes based on their ``part_of`` entries.
 
-        :returns:
-            A dictionary with keys that appear as the values of ``Resource.part_of``
-            and whose values are lists of prefixes for resources that have the key
-            as a value in its ``part_of`` field.
+        :returns: A dictionary with keys that appear as the values of
+            ``Resource.part_of`` and whose values are lists of prefixes for resources
+            that have the key as a value in its ``part_of`` field.
 
         .. warning::
 
-            Many of the keys in this dictionary are valid Bioregistry prefixes,
-            but this is not necessary. For example, ``ctd`` is one key that
-            appears that explicitly has no prefix, since it corresponds to a
-            resource and not a vocabulary.
+            Many of the keys in this dictionary are valid Bioregistry prefixes, but this
+            is not necessary. For example, ``ctd`` is one key that appears that
+            explicitly has no prefix, since it corresponds to a resource and not a
+            vocabulary.
         """
         rv = {}
         for key, values in self.has_parts.items():
@@ -1414,7 +1423,8 @@ class Manager:
 
         :param prefix: The prefix in the CURIE
         :param identifier: The identifier in the CURIE
-        :return: A link to the Bioregistry resolver
+
+        :returns: A link to the Bioregistry resolver
         """
         reference = self.normalize_parsed_curie(
             prefix, identifier, on_failure_return_type=FailureReturnType.single
@@ -1428,7 +1438,8 @@ class Manager:
 
         :param prefix: The prefix in the CURIE
         :param identifier: The identifier in the CURIE
-        :return: A IRI string corresponding to the default provider, if available.
+
+        :returns: A IRI string corresponding to the default provider, if available.
 
         >>> from bioregistry import manager
         >>> manager.get_default_iri("chebi", "24867")
@@ -1444,7 +1455,9 @@ class Manager:
 
         :param prefix: The prefix in the CURIE
         :param identifier: The identifier in the CURIE
-        :return: A IRI string corresponding to the canonical RDF provider, if available.
+
+        :returns: A IRI string corresponding to the canonical RDF provider, if
+            available.
 
         >>> from bioregistry import manager
         >>> manager.get_rdf_uri("edam", "data_1153")
@@ -1467,8 +1480,9 @@ class Manager:
 
         :param prefix: The prefix in the CURIE
         :param identifier: The identifier in the CURIE
-        :return: A IRI string corresponding to the Identifiers.org, if the prefix exists and is
-            mapped to MIRIAM.
+
+        :returns: A IRI string corresponding to the Identifiers.org, if the prefix
+            exists and is mapped to MIRIAM.
         """
         curie = self.get_miriam_curie(prefix, identifier)
         if curie is None:
@@ -1480,7 +1494,8 @@ class Manager:
 
         :param prefix: The prefix in the CURIE
         :param identifier: The identifier in the CURIE
-        :return: A link to the Bioportal page
+
+        :returns: A link to the Bioportal page
 
         >>> from bioregistry import manager
         >>> manager.get_bioportal_iri("chebi", "24431")
@@ -1506,10 +1521,12 @@ class Manager:
         """Get an IRI using the format in the metaregistry.
 
         :param metaprefix: The metaprefix of the registry in the metaregistry
-        :param prefix: A bioregistry prefix (will be mapped to the external one automatically)
+        :param prefix: A bioregistry prefix (will be mapped to the external one
+            automatically)
         :param identifier: The identifier for the entity
-        :returns: An IRI generated from the ``resolver_url`` format string of the registry, if it
-            exists.
+
+        :returns: An IRI generated from the ``resolver_url`` format string of the
+            registry, if it exists.
 
         >>> from bioregistry import manager
         >>> manager.get_formatted_iri("miriam", "hgnc", "16793")
@@ -1530,7 +1547,9 @@ class Manager:
 
         :param prefix: The prefix
         :param identifier: The identifier
-        :return: The OBO Foundry URL if the prefix can be mapped to an OBO Foundry entry
+
+        :returns: The OBO Foundry URL if the prefix can be mapped to an OBO Foundry
+            entry
 
         >>> from bioregistry import manager
         >>> manager.get_obofoundry_iri("chebi", "24431")
@@ -1548,8 +1567,9 @@ class Manager:
 
         :param prefix: The prefix in the CURIE
         :param identifier: The identifier in the CURIE
-        :return: A IRI string corresponding to the N2T resolve, if the prefix exists and is
-            mapped to N2T.
+
+        :returns: A IRI string corresponding to the N2T resolve, if the prefix exists
+            and is mapped to N2T.
 
         >>> from bioregistry import manager
         >>> manager.get_n2t_iri("chebi", "24867")
@@ -1562,8 +1582,9 @@ class Manager:
 
         :param prefix: The prefix in the CURIE
         :param identifier: The identifier in the CURIE
-        :return: A IRI string corresponding to the RRID resolver, if the prefix exists and is
-            mapped to RRID.
+
+        :returns: A IRI string corresponding to the RRID resolver, if the prefix exists
+            and is mapped to RRID.
 
         >>> from bioregistry import manager
         >>> manager.get_rrid_iri("antibodyregistry", "493771")
@@ -1576,7 +1597,8 @@ class Manager:
 
         :param prefix: The prefix in the CURIE
         :param identifier: The identifier in the CURIE
-        :return: A link to the Scholia page
+
+        :returns: A link to the Scholia page
 
         >>> from bioregistry import manager
         >>> manager.get_scholia_iri("pubmed", "1234")
@@ -1650,6 +1672,7 @@ class Manager:
 
         :param prefix: the prefix in the CURIE
         :param identifier: the identifier in the CURIE
+
         :returns: A dictionary of IRIs associated with the CURIE
 
         >>> from bioregistry import manager
@@ -1662,10 +1685,11 @@ class Manager:
 
         :param metaprefix: The metaprefix for an external registry
         :param prefix: The Bioregistry prefix
-        :param identifier: The local unique identifier for a concept in the semantic space
-            denoted by the prefix
-        :returns: The external registry's URI (either for resolving or lookup) of the entity
-            denoted by the prefix/identifier pair.
+        :param identifier: The local unique identifier for a concept in the semantic
+            space denoted by the prefix
+
+        :returns: The external registry's URI (either for resolving or lookup) of the
+            entity denoted by the prefix/identifier pair.
 
         >>> from bioregistry import manager
         >>> manager.get_registry_uri("rrid", "antibodyregistry", "493771")
@@ -1693,45 +1717,56 @@ class Manager:
         """Get the best link for the CURIE pair, if possible.
 
         :param prefix: The prefix in the CURIE
-        :param identifier: The identifier in the CURIE. If identifier is given as None, then this function will
-            assume that the first argument (``prefix``) is actually a full CURIE.
-        :param priority: A user-defined priority list. In addition to the metaprefixes in the Bioregistry
-            corresponding to resources that are resolvers/lookup services, you can also use ``default``
-            to correspond to the first-party IRI and ``custom`` to refer to the custom prefix map.
-            The default priority list is:
+        :param identifier: The identifier in the CURIE. If identifier is given as None,
+            then this function will assume that the first argument (``prefix``) is
+            actually a full CURIE.
+        :param priority: A user-defined priority list. In addition to the metaprefixes
+            in the Bioregistry corresponding to resources that are resolvers/lookup
+            services, you can also use ``default`` to correspond to the first-party IRI
+            and ``custom`` to refer to the custom prefix map. The default priority list
+            is:
 
             1. Custom prefix map (``custom``)
-            1. First-party IRI (``default``)
-            2. Identifiers.org / MIRIAM (``miriam``)
-            3. Ontology Lookup Service (``ols``)
-            4. OBO PURL (``obofoundry``)
-            5. Name-to-Thing (``n2t``)
-            6. BioPortal (``bioportal``)
-        :param prefix_map: A custom prefix map to go with the ``custom`` key in the priority list
-        :param use_bioregistry_io: Should the bioregistry resolution IRI be used? Defaults to true.
+            2. First-party IRI (``default``)
+            3. Identifiers.org / MIRIAM (``miriam``)
+            4. Ontology Lookup Service (``ols``)
+            5. OBO PURL (``obofoundry``)
+            6. Name-to-Thing (``n2t``)
+            7. BioPortal (``bioportal``)
+        :param prefix_map: A custom prefix map to go with the ``custom`` key in the
+            priority list
+        :param use_bioregistry_io: Should the bioregistry resolution IRI be used?
+            Defaults to true.
         :param provider: The provider code to use for a custom provider
-        :return: The best possible IRI that can be generated based on the priority list.
+
+        :returns: The best possible IRI that can be generated based on the priority
+            list.
 
         A pre-parse CURIE can be given as the first two arguments
+
         >>> from bioregistry import manager
         >>> manager.get_iri("chebi", "24867")
         'http://purl.obolibrary.org/obo/CHEBI_24867'
 
         A CURIE can be given directly as a single argument
+
         >>> manager.get_iri("chebi:24867")
         'http://purl.obolibrary.org/obo/CHEBI_24867'
 
         A priority list can be given
+
         >>> priority = ["miriam", "default", "bioregistry"]
         >>> manager.get_iri("chebi:24867", priority=priority)
         'https://identifiers.org/CHEBI:24867'
 
         A custom prefix map can be supplied.
+
         >>> prefix_map = {"chebi": "https://example.org/chebi/"}
         >>> manager.get_iri("chebi:24867", prefix_map=prefix_map)
         'https://example.org/chebi/24867'
 
         A custom prefix map can be supplied in combination with a priority list
+
         >>> prefix_map = {"lipidmaps": "https://example.org/lipidmaps/"}
         >>> priority = ["obofoundry", "custom", "default", "bioregistry"]
         >>> manager.get_iri("chebi:24867", prefix_map=prefix_map, priority=priority)
@@ -1740,6 +1775,7 @@ class Manager:
         'https://example.org/lipidmaps/1234'
 
         A custom provider is given, which makes the Bioregistry very extensible
+
         >>> manager.get_iri("chebi:24867", provider="chebi-img")
         'https://www.ebi.ac.uk/chebi/displayImage.do?defaultImage=true&imageIndex=0&chebiId=24867'
         """
@@ -1809,29 +1845,35 @@ class Manager:
 
         :param prefix: The prefix from a compact URI
         :param identifier: The local unique identifer from a compact URI
-        :return:
-            If the CURIE is standardized in both syntax and semantics. This means that it uses the Bioregistry
-            canonical prefix, does not have a redundant prefix, and if available, matches the Bioregistry's
-            regular expression pattern for identifiers.
+
+        :returns: If the CURIE is standardized in both syntax and semantics. This means
+            that it uses the Bioregistry canonical prefix, does not have a redundant
+            prefix, and if available, matches the Bioregistry's regular expression
+            pattern for identifiers.
 
         Standard CURIE
+
         >>> from bioregistry import manager
         >>> manager.is_valid_identifier("go", "0000001")
         True
 
         Non-standardized prefix
+
         >>> manager.is_valid_identifier("GO", "0000001")
         False
 
         Incorrect identifier
+
         >>> manager.is_valid_identifier("go", "0001")
         False
 
         Banana scenario
+
         >>> manager.is_valid_identifier("go", "GO:0000001")
         False
 
         Unknown prefix
+
         >>> manager.is_valid_identifier("xxx", "yyy")
         False
         """
@@ -1845,28 +1887,33 @@ class Manager:
 
         :param prefix: The prefix from a compact URI
         :param identifier: The local unique identifer from a compact URI
-        :return:
-            If the CURIE can be standardized (e.g., prefix normalize and identifier normalized)
-            then validated.
+
+        :returns: If the CURIE can be standardized (e.g., prefix normalize and
+            identifier normalized) then validated.
 
         Standard CURIE
+
         >>> from bioregistry import manager
         >>> manager.is_standardizable_identifier("go", "0000001")
         True
 
         Non-standardized prefix
+
         >>> manager.is_standardizable_identifier("GO", "0000001")
         True
 
         Incorrect identifier
+
         >>> manager.is_standardizable_identifier("go", "0001")
         False
 
         Banana scenario
+
         >>> manager.is_standardizable_identifier("go", "GO:0000001")
         True
 
         Unknown prefix
+
         >>> manager.is_standardizable_identifier("xxx", "yyy")
         False
         """
@@ -1879,17 +1926,20 @@ class Manager:
         """Check if a CURIE is standardized and valid.
 
         :param curie: A compact URI of the form ``<prefix>:<local unique identifier>``.
-        :return:
-            If the CURIE is standardized in both syntax and semantics. This means that it uses the Bioregistry
-            canonical prefix, does not have a redundant prefix, and if available, matches the Bioregistry's
-            regular expression pattern for identifiers.
+
+        :returns: If the CURIE is standardized in both syntax and semantics. This means
+            that it uses the Bioregistry canonical prefix, does not have a redundant
+            prefix, and if available, matches the Bioregistry's regular expression
+            pattern for identifiers.
 
         Standard CURIE
+
         >>> from bioregistry import manager
         >>> manager.is_valid_curie("go:0000001")
         True
 
         Not a standard CURIE (i.e., no colon)
+
         >>> manager.is_valid_curie("0000001")
         False
         >>> manager.is_valid_curie("GO_0000001")
@@ -1898,18 +1948,22 @@ class Manager:
         False
 
         Non-standardized prefix
+
         >>> manager.is_valid_curie("GO:0000001")
         False
 
         Incorrect identifier
+
         >>> manager.is_valid_curie("go:0001")
         False
 
         Banana scenario
+
         >>> manager.is_valid_curie("go:GO:0000001")
         False
 
         Unknown prefix
+
         >>> manager.is_valid_curie("xxx:yyy")
         False
         """
@@ -1923,15 +1977,18 @@ class Manager:
         """Check if a CURIE is validatable, but not necessarily standardized.
 
         :param curie: A compact URI
-        :return: If the CURIE can be standardized (e.g., prefix normalize and identifier normalized)
-            then validated.
+
+        :returns: If the CURIE can be standardized (e.g., prefix normalize and
+            identifier normalized) then validated.
 
         Standard CURIE
+
         >>> from bioregistry import manager
         >>> manager.is_standardizable_curie("go:0000001")
         True
 
         Not a standard CURIE (i.e., no colon)
+
         >>> manager.is_standardizable_curie("0000001")
         False
         >>> manager.is_standardizable_curie("GO_0000001")
@@ -1940,18 +1997,22 @@ class Manager:
         False
 
         Non-standardized prefix
+
         >>> manager.is_standardizable_curie("GO:0000001")
         True
 
         Incorrect identifier
+
         >>> manager.is_standardizable_curie("go:0001")
         False
 
         Banana scenario
+
         >>> manager.is_standardizable_curie("go:GO:0000001")
         True
 
         Unknown prefix
+
         >>> manager.is_standardizable_curie("xxx:yyy")
         False
         """
@@ -1965,6 +2026,7 @@ class Manager:
         """Get a prescriptive context.
 
         :param key: The identifier for the prescriptive context, e.g., `obo`.
+
         :returns: A prescriptive context object, if available
         """
         return self.contexts.get(key)
